@@ -26,11 +26,11 @@ signals.post_syncdb.connect(bootup)
 # when a user is created and saved to db, a profile for that user is created
 if getattr(settings, 'AUTH_PROFILE_MODULE', False):
     # latch on user creation if flag is set
-    if getattr(settings, 'USER_PROFILE_AUTO_CREATE', False):
+    if getattr(settings, 'BOOTUP_USER_PROFILE_AUTO_CREATE', False):
         signals.post_save.connect(create_profile, sender=User)
 
         # latch on user deletion if flag if both (create & delete) flags are set
-        if getattr(settings, 'USER_PROFILE_AUTO_DELETE', False):
+        if getattr(settings, 'BOOTUP_USER_PROFILE_AUTO_DELETE', False):
             signals.post_delete.connect(delete_profile, sender=User)
 
 
