@@ -6,11 +6,11 @@ MAIN_DOMAIN_NAME = "example.com"
 TEST_DOMAIN_NAME = "example.net"
 LOCAL_IP = "192.168.224.128"
 LOCAL_PORT = "8080"
-ADMIN_NAME = "admin"
-MAIN_PASS = "mypasseh?"
-ADMIN_EMAIL = ADMIN_NAME+"@"+MAIN_DOMAIN_NAME
+BOOTUP_SUPERUSER_NAME = "admin"
+BOOTUP_SUPERUSER_PASSWORD = "mypasseh?"
+BOOTUP_SUPERUSER_EMAIL = BOOTUP_SUPERUSER_NAME+"@"+MAIN_DOMAIN_NAME
 
-SITE_INFO = {
+BOOTUP_SITES = {
     '1': {
         'name': 'production',
         'domain': MAIN_DOMAIN_NAME
@@ -45,8 +45,8 @@ INSTALLED_APPS = [
 
 # django profiles
 AUTH_PROFILE_MODULE = 'bootup.UserProfile'
-USER_PROFILE_AUTO_CREATE = True
-USER_PROFILE_AUTO_DELETE = True
+BOOTUP_USER_PROFILE_AUTO_CREATE = True
+BOOTUP_USER_PROFILE_AUTO_DELETE = True
 
 
 
